# For this specific map, the area relative to the player's vision in which npcs are searched has been changed to better suit the mobs used as npc  

# Changes to 1.0 commands: added first and fourth command for text, changed data modify to execute on each villager

# Change on 2020-05-13: instead of "positioned ^ ^0.4 ^1.6 if entity @e[distance=..0.7]", the second command is used in its place
# The command is more precise (uses the entity's centre), while also requiring less precision from the player (thanks u/TinyBreadBigMouth for the command)
# This also changes the way the tag "active" is used, being what triggers the commands that used "positioned..."
# "unless..." in the first command fixes a bug where, if the player walked away from the npc while starting the dialogue, they could be able to remove "active" after the fade started
# In this way, instead, "active" is removed only if the starting fade hasn't started, making the player unable to break free from the dialogue after having started it
execute unless entity @a[tag=dissolve_start] run tag @e[type=!player,tag=npc,tag=active] remove active
execute as @a[gamemode=!spectator] at @s anchored eyes facing entity @e[tag=npc,tag=!active,limit=1,sort=nearest,distance=..2.5] eyes anchored feet positioned ^ ^ ^1 rotated as @s positioned ^ ^ ^-1 if entity @s[distance=..0.5] at @s run tag @e[tag=npc,tag=!active,limit=1,sort=nearest,distance=..2.5] add active

# These commands are for visual effects:

# These control the text on top of the hotbar
title @a[tag=npc,tag=active] actionbar ["",{"text":"Right click to interact","bold":true,"italic":true,"color":"dark_gray"}]
execute if entity @e[tag=active,tag=npc] run title @a actionbar ["",{"text":"Right click to interact","bold":true,"italic":true,"color":"dark_gray"}]
execute unless entity @e[tag=active,tag=npc] run title @a actionbar ["",{"text":"","bold":true,"italic":true}]
execute as @a[tag=!npc,tag=active] run title @a actionbar ["",{"text":"","bold":true,"italic":true}]

# These control the glowing effect added to interactibles with the tag "glow"
# Modified first command and added two more to clear the effect once the dialogue has started
execute unless entity @a[scores={fade=1..}] run effect give @e[tag=active,tag=glow,limit=1,sort=nearest] glowing 1 1 true
effect clear @e[tag=!active,tag=glow] glowing

execute if entity @a[tag=npc] run effect clear @e[tag=glow] glowing
execute if entity @a[scores={fade=1..}] run effect clear @e[tag=glow] glowing

# These commands control the villager mob used for the right click detection and the tag "active"
# 2.0 - changed some selectors from @e to @a, made the first command shorter and split "add active" in one command for the players and one for the entities

# 2020-08-30 - changed command to still spawn only one villager, but without needing to require a player without the tag active
# Old command was "execute at @a[gamemode=!spectator,tag=npc,tag=!active] run..."
execute at @a[gamemode=!spectator,tag=npc] unless entity @e[type=villager,tag=right] run summon villager ~ ~ ~ {Silent:1b,Invulnerable:1b,NoGravity:1b,PersistenceRequired:1b,NoAI:1b,CareerLevel:100,Offers:{Recipes:[]},ActiveEffects:[{Id:14,Duration:10000000,Amplifier:0b,ShowParticles:0b}],Tags:["right"]}
tag @a[tag=npc] add active

execute as @a[tag=npc,tag=!active] at @s run execute as @e[tag=right,type=villager,distance=0] run data merge entity @s {Health:0f,DeathTime:19}
# 2.0 - Changed command adding tag=active to make sure villagers are teleported only to activated players (omitting tag=npc makes sure it works also for the frame after removing npc)
execute as @e[type=villager,tag=right] at @s run tp @s @a[limit=1,sort=nearest,tag=active]

# 2.0 - Now the villager only spawns on the player and not on the npcs to make the right click detection more consistent and to support npcs with an hitbox
# This had the effect of not requiring the player to face the npc to start the dialogue, so "distance=..2" has been replaced with "positioned ^ ^0.4 ^1.6 if entity @e[distance=..0.7]"
# 2020-05-13: "positioned..." commands changed to use "active" as the new requisite
execute as @a at @s if entity @e[type=!player,tag=npc,tag=active,distance=..2.5] run tag @s add start_npc
execute as @a[tag=start_npc] at @s unless entity @e[type=villager,tag=start_right] run summon villager ~ ~ ~ {Silent:1b,Invulnerable:1b,NoGravity:1b,PersistenceRequired:1b,NoAI:1b,CareerLevel:100,Offers:{Recipes:[]},ActiveEffects:[{Id:14,Duration:10000000,Amplifier:0b,ShowParticles:0b}],Tags:["start_right"]}
execute as @a[tag=!start_npc] at @s run execute as @e[tag=start_right,type=villager] run data merge entity @s {Health:0f,DeathTime:19}

execute as @e[type=villager,tag=start_right] at @s run tp @s @a[limit=1,sort=nearest,tag=start_npc]
# 2020-12-06 - command to fix the strangest bug I've ever encountered; start_right villagers are now teleported in front of the player, instead of on them
# For more info: https://www.reddit.com/r/MinecraftCommands/comments/k7vdl5/the_strangest_bug_ive_ever_encountered_right/?
execute as @e[type=villager,tag=start_right] at @s at @a[limit=1,sort=nearest,tag=start_npc] positioned ^ ^ ^0.47 run tp @s ~ ~ ~

execute as @a[tag=start_npc] at @s unless entity @e[type=!player,tag=npc,tag=active,distance=..2.5] run tag @s remove start_npc

# These commands control the score "dialogue"
# 2.0 - added first command and changed @e to @a in the second

execute as @a[scores={right=1}] at @s run scoreboard players set @e[type=!player,limit=1,sort=nearest,tag=active] dialogue 1
execute as @a[scores={right=1}] at @s run scoreboard players add @a[limit=1,sort=nearest,tag=active] dialogue 1
execute as @a[scores={right=1..}] run scoreboard players add @s right 1
execute as @a[scores={right=3..}] run scoreboard players reset @s right
scoreboard players reset @e[tag=!active,tag=!keep] dialogue

# Addded to fix the bug that, for some reason, doesn't happen in Unexpected Past
# After trying to change 1.0 commands, it has been found that it wasn't a problem because the villagers were teleported to other npcs and there killed (command has been changed)
execute as @e[tag=!npc,tag=active] at @s run execute as @e[tag=right,type=villager,distance=0] run data merge entity @s {Health:0f,DeathTime:19}

# These commands control the player's tag and team

tag @a[tag=!npc] remove active
scoreboard players reset @a[tag=!npc] dialogue
team join collisionPE @a[tag=npc]
team leave @a[tag=!npc]

# 2.0
team join collisionPE @e[type=villager,tag=right]
team join collisionPE @e[type=villager,tag=start_right]

team join collisionPE @a[tag=start_npc]
team leave @a[tag=!start_npc]


# 2020-09-13 - Added option to stop the player from advancing the current dialogue by giving the tag "stop_dialogue"
scoreboard players set @a[tag=stop_dialogue] right -1
scoreboard players set @a[scores={right=-1},tag=!stop_dialogue] right 0


# If the npc tag is removed from an active npc, the  active tag will remain and, with it, the current dialogue score of the npc; this can be used by other commands

# Dialogue system v2.0

# Commands to make the player immobile if they have the tag stop (combined with npc when needed)
execute at @a[tag=stop] unless entity @e[tag=stop_player] run summon armor_stand ~ ~ ~ {Marker:true,NoGravity:true,Invisible:true,Small:true,Pose:{LeftArm:[0f,0f,45f]},Tags:["stop_player"]}
execute at @a[tag=!stop] run kill @e[tag=stop_player]
execute at @e[tag=stop_player] run tp @a[tag=stop] ^ ^ ^

# Removed: the dialogue does already this and the command was buggy with the dissolve effect applied
# Makes the player immobile for dialogues with other npcs
# execute at @a run execute at @e[tag=dialogue_stand,limit=1,sort=nearest] run tp @a[tag=npc,tag=!fade_out,tag=!fade_in] ^ ^ ^

# When a dialogue starts, the villager used for the start dialogue interaction is killed
execute as @e[tag=active,scores={dialogue=1},type=!player] at @s if entity @p[scores={right=2}] run data merge entity @e[tag=right,type=villager,distance=0,limit=1] {Health:0f,DeathTime:19}
# On the second interaction, the npc score is reset (this could be done on the first one by removing "if...", but, in this way, costant actions can be done during it, like tp facing)
execute as @e[tag=active,scores={dialogue=1},tag=!npc] at @s if entity @p[scores={right=2},tag=npc] run scoreboard players reset @s dialogue

# About entities used by the dialogues:
# player_puppet is a marker: it should be kept invisible and on it the true player model should be spawned using this command:
# execute at @e[tag=player_puppet] unless entity @e[tag=player_model] run summon <entity for the model> ^ ^ ^ {Tags:["player_model"]}
# If the entity used has a right click interaction, it has to be removed; for example, armor stands need Marker:true
# This makes still possible to give the held item to the model, even if it does not support an held item

# These commands will face the player model towards the npc and remove it at the end of the dialogue
# 2020-09-08 - Added requirement "tag=!free_look" to be able to manually set the rotation of the model
# 2020-12-11 - Added requirement "tag=!no_look", tag given to npcs when needed (for example, for npcs without a dialogue used for other reasons)
execute at @e[tag=player_puppet] run tp @e[tag=player_model,limit=1,sort=nearest,tag=!free_look] ^ ^ ^ facing entity @e[tag=npc_puppet,limit=1,sort=nearest,tag=!no_look]
execute unless entity @e[tag=player_puppet] run data merge entity @e[tag=player_model,limit=1] {Health:0f,DeathTime:19}
execute unless entity @e[tag=player_puppet] run kill @e[tag=player_model]

# Dissolve effect
scoreboard players add @a[scores={fade=0..}] fade 1
# Removed: applied by commands with fade, let's more than one fade with different timing coexist
#scoreboard players reset @a[scores={fade=25..99}] fade
#scoreboard players reset @a[scores={fade=125..}] fade
scoreboard players reset @a[tag=reset_fade] fade
# 2020-05-14: reset_fade also kills the armor stand used to store the player's offhand item
execute as @a[tag=reset_fade] run kill @e[tag=fade_puppet]
execute as @a[tag=reset_fade] unless entity @s[scores={fade=1..}] run tag @s remove reset_fade

# The next command makes the fade in work even if the player has been teleported, but it's not immediate
execute at @a run tp @e[tag=fade] ~ ~1 ~
# To make the effect work better, deactivate the command and teleport the armor stands before of the player in the designated place
# Alternately, you can add the next commands to give and remove from the player a pumpkin (change the overlay to pure black)
replaceitem entity @a[tag=fade_out,scores={fade=18}] armor.head carved_pumpkin{CustomModelData:1,Enchantments:[{id:"binding_curse",lvl:1}],display:{Name:"[{\"text\":\"\"}]"}}
replaceitem entity @a[tag=fade_in,scores={fade=101}] armor.head air

# Command possibly useful to avoid some bugs (no direct use found)
# If active, the next command will have the effect to stop the player from being able to restart immediately the dialogue by spamming right click
# scoreboard players reset @a[scores={fade=1..}] right

# Fade out
tag @a[tag=fade_out] add stop
execute as @a[tag=fade_out] unless entity @s[scores={fade=1..}] run scoreboard players set @s fade 0
execute at @a[tag=fade_out,scores={fade=1}] run summon armor_stand ~ ~1 ~ {ArmorItems:[{},{},{},{id:coal,Count:1b,tag:{CustomModelData:10}}],Marker:true,NoGravity:true,Invisible:true,Tags:["fade","1"]}
execute at @a[tag=fade_out,scores={fade=4}] run summon armor_stand ~ ~1 ~ {ArmorItems:[{},{},{},{id:coal,Count:1b,tag:{CustomModelData:10}}],Marker:true,NoGravity:true,Invisible:true,Tags:["fade","2"]}
execute at @a[tag=fade_out,scores={fade=7}] run summon armor_stand ~ ~1 ~ {ArmorItems:[{},{},{},{id:coal,Count:1b,tag:{CustomModelData:10}}],Marker:true,NoGravity:true,Invisible:true,Tags:["fade","3"]}
execute at @a[tag=fade_out,scores={fade=10}] run summon armor_stand ~ ~1 ~ {ArmorItems:[{},{},{},{id:coal,Count:1b,tag:{CustomModelData:10}}],Marker:true,NoGravity:true,Invisible:true,Tags:["fade","4"]}
execute at @a[tag=fade_out,scores={fade=13}] run summon armor_stand ~ ~1 ~ {ArmorItems:[{},{},{},{id:coal,Count:1b,tag:{CustomModelData:10}}],Marker:true,NoGravity:true,Invisible:true,Tags:["fade","5"]}
execute at @a[tag=fade_out,scores={fade=16}] run summon armor_stand ~ ~1 ~ {ArmorItems:[{},{},{},{id:coal,Count:1b,tag:{CustomModelData:10}}],Marker:true,NoGravity:true,Invisible:true,Tags:["fade","6"]}
execute at @a[tag=fade_out,scores={fade=19}] run summon armor_stand ~ ~1 ~ {ArmorItems:[{},{},{},{id:coal,Count:1b,tag:{CustomModelData:10}}],Marker:true,NoGravity:true,Invisible:true,Tags:["fade","7"]}
effect give @a[tag=fade_out,scores={fade=19}] blindness 2 2 true
tag @a[tag=fade_out,scores={fade=19}] add reset_fade
tag @a[tag=fade_out,scores={fade=19}] remove fade_out

# Fade in
effect clear @a[tag=fade_in] blindness
execute as @a[tag=fade_in] unless entity @s[scores={fade=1..}] run scoreboard players set @s fade 100
execute at @a[tag=fade_in,scores={fade=101}] run kill @e[tag=fade,tag=7]
execute at @a[tag=fade_in,scores={fade=104}] run kill @e[tag=fade,tag=6]
execute at @a[tag=fade_in,scores={fade=107}] run kill @e[tag=fade,tag=5]
execute at @a[tag=fade_in,scores={fade=110}] run kill @e[tag=fade,tag=4]
execute at @a[tag=fade_in,scores={fade=113}] run kill @e[tag=fade,tag=3]
execute at @a[tag=fade_in,scores={fade=116}] run kill @e[tag=fade,tag=2]
execute at @a[tag=fade_in,scores={fade=119}] run kill @e[tag=fade,tag=1]
tag @a[tag=fade_in,scores={fade=119}] remove stop
tag @a[tag=fade_in,scores={fade=119}] add reset_fade
tag @a[tag=fade_in,scores={fade=119}] remove fade_in

# Blindness is applied to improve the transition between fade out and fade in

# Dissolve with items - needs the off hand slot freely usable, but makes the effect more consistent, less laggy and not teleport dependent
# 2020-05-14: changed commands so that items in the offhand, that are not used by the effect, are given back for the whole duration of the fade
# If the player puts an item in the offhand during the fade, they will receive back the item, but the effect will break (the objective "fade" continues to increase)

tp @e[tag=fade_puppet] @a[limit=1,sort=nearest,scores={fade=0..}]

# If the player has an item in their off hand, it will be give back at the end of the effect
# 2020-05-14: changed commands so that they work for the whole duration of the fade effect
execute as @a[scores={fade=0..}] unless entity @s[nbt={Inventory:[{Slot:-106b,tag:{fade:true}}]}] run data modify entity @e[limit=1,tag=fade_puppet] HandItems[1] set from entity @s Inventory[{Slot:-106b}]
execute as @a[scores={fade=0..}] unless entity @s[nbt={Inventory:[{Slot:-106b,tag:{fade:true}}]}] run replaceitem entity @s weapon.offhand air
execute as @a[scores={fade=0..}] unless entity @s[nbt={Inventory:[{Slot:-106b,tag:{fade:true}}]}] at @s run summon item ~ ~ ~ {Item:{id:black_concrete,Count:1b,tag:{offhand:true}}}
execute as @a[scores={fade=0..}] unless entity @s[nbt={Inventory:[{Slot:-106b,tag:{fade:true}}]}] at @s run data modify entity @e[type=item,limit=1,sort=nearest,nbt={Item:{tag:{offhand:true}}}] Item set from entity @e[tag=fade_puppet,limit=1] HandItems[1]
execute as @a[scores={fade=0..}] unless entity @s[nbt={Inventory:[{Slot:-106b,tag:{fade:true}}]}] run replaceitem entity @e[tag=fade_puppet] weapon.offhand air


# Fade out
# The second command has "if..." to make sure the fade_puppet armor stand exist before the player receives the items
execute at @a[tag=fade_out_F] unless entity @e[tag=fade_puppet] run summon armor_stand ~ ~ ~ {Marker:true,NoGravity:true,Invisible:true,Small:true,Pose:{LeftArm:[0f,0f,45f]},Tags:["fade_puppet"]}
# 2020-05-14: made stop optional
tag @a[tag=fade_out_F] add stop
# 2020-05-14: added clear before every replaceitem in case the player disrupts with the fade effect by putting items in the offhand
execute as @a[tag=fade_out_F] at @s if entity @e[tag=fade_puppet,limit=1,sort=nearest] unless entity @s[scores={fade=1..}] run scoreboard players set @s fade 0
execute as @a[tag=fade_out_F,scores={fade=1}] run replaceitem entity @s weapon.offhand coal{CustomModelData:7,display:{Name:"[{\"text\":\"\"}]"},fade:true}
execute as @a[tag=fade_out_F,scores={fade=3}] run clear @s coal{fade:true}
execute as @a[tag=fade_out_F,scores={fade=3}] run replaceitem entity @s weapon.offhand coal{CustomModelData:6,display:{Name:"[{\"text\":\"\"}]"},fade:true}
execute as @a[tag=fade_out_F,scores={fade=5}] run clear @s coal{fade:true}
execute as @a[tag=fade_out_F,scores={fade=5}] run replaceitem entity @s weapon.offhand coal{CustomModelData:5,display:{Name:"[{\"text\":\"\"}]"},fade:true}
execute as @a[tag=fade_out_F,scores={fade=7}] run clear @s coal{fade:true}
execute as @a[tag=fade_out_F,scores={fade=7}] run replaceitem entity @s weapon.offhand coal{CustomModelData:4,display:{Name:"[{\"text\":\"\"}]"},fade:true}
execute as @a[tag=fade_out_F,scores={fade=9}] run clear @s coal{fade:true}
execute as @a[tag=fade_out_F,scores={fade=9}] run replaceitem entity @s weapon.offhand coal{CustomModelData:3,display:{Name:"[{\"text\":\"\"}]"},fade:true}
execute as @a[tag=fade_out_F,scores={fade=11}] run clear @s coal{fade:true}
execute as @a[tag=fade_out_F,scores={fade=11}] run replaceitem entity @s weapon.offhand coal{CustomModelData:2,display:{Name:"[{\"text\":\"\"}]"},fade:true}
execute as @a[tag=fade_out_F,scores={fade=13}] run clear @s coal{fade:true}
execute as @a[tag=fade_out_F,scores={fade=13}] run replaceitem entity @s weapon.offhand coal{CustomModelData:1,display:{Name:"[{\"text\":\"\"}]"},fade:true}
tag @a[tag=fade_out_F,scores={fade=13}] add reset_fade
tag @a[tag=fade_out_F,scores={fade=13}] remove fade_out_F


# Fade in
execute at @a[tag=fade_in_F] unless entity @e[tag=fade_puppet] run summon armor_stand ~ ~ ~ {Marker:true,NoGravity:true,Invisible:true,Small:true,Pose:{LeftArm:[0f,0f,45f]},Tags:["fade_puppet"]}
execute as @a[tag=fade_in_F] unless entity @s[scores={fade=1..}] run scoreboard players set @s fade 100
# 2020-05-14: added clear before every replaceitem in case the player disrupts with the fade effect by putting items in the offhand
execute as @a[tag=fade_in_F,scores={fade=101}] run replaceitem entity @s weapon.offhand coal{CustomModelData:1,display:{Name:"[{\"text\":\"\"}]"},fade:true}
execute as @a[tag=fade_in_F,scores={fade=103}] run clear @s coal{fade:true}
execute as @a[tag=fade_in_F,scores={fade=103}] run replaceitem entity @s weapon.offhand coal{CustomModelData:2,display:{Name:"[{\"text\":\"\"}]"},fade:true}
execute as @a[tag=fade_in_F,scores={fade=105}] run clear @s coal{fade:true}
execute as @a[tag=fade_in_F,scores={fade=105}] run replaceitem entity @s weapon.offhand coal{CustomModelData:3,display:{Name:"[{\"text\":\"\"}]"},fade:true}
execute as @a[tag=fade_in_F,scores={fade=107}] run clear @s coal{fade:true}
execute as @a[tag=fade_in_F,scores={fade=107}] run replaceitem entity @s weapon.offhand coal{CustomModelData:4,display:{Name:"[{\"text\":\"\"}]"},fade:true}
execute as @a[tag=fade_in_F,scores={fade=109}] run clear @s coal{fade:true}
execute as @a[tag=fade_in_F,scores={fade=109}] run replaceitem entity @s weapon.offhand coal{CustomModelData:5,display:{Name:"[{\"text\":\"\"}]"},fade:true}
execute as @a[tag=fade_in_F,scores={fade=111}] run clear @s coal{fade:true}
execute as @a[tag=fade_in_F,scores={fade=111}] run replaceitem entity @s weapon.offhand coal{CustomModelData:6,display:{Name:"[{\"text\":\"\"}]"},fade:true}
execute as @a[tag=fade_in_F,scores={fade=113}] run clear @s coal{fade:true}
execute as @a[tag=fade_in_F,scores={fade=113}] run replaceitem entity @s weapon.offhand coal{CustomModelData:7,display:{Name:"[{\"text\":\"\"}]"},fade:true}
execute as @a[tag=fade_in_F,scores={fade=115}] run clear @s coal{fade:true}
# 2020-05-14: made stop optional
tag @a[tag=fade_in_F,scores={fade=115}] remove stop
tag @a[tag=fade_in_F,scores={fade=115}] add reset_fade
tag @a[tag=fade_in_F,scores={fade=115}] remove fade_in_F


# Tags applied during dissolve to control other commands like the setup of the dialogue (in this way, the timing can be changed by just changing the dissolve's commands)
# fade_start isn't really needed (the start always is at fade=1, even if the timing is changed), but was added for consistency
tag @a[scores={fade=0}] add fade_start
execute as @a unless entity @s[scores={fade=0}] run tag @s remove fade_start
# 2020-08-29 - fade_stands is before the end of the fade out because the stands have to be spawned before the player is teleported to them
tag @a[scores={fade=11}] add fade_stands
execute as @a unless entity @s[scores={fade=11}] run tag @s remove fade_stands
tag @a[scores={fade=12}] add fade_out_end
execute as @a unless entity @s[scores={fade=12}] run tag @s remove fade_out_end
# 2020-08-29 - added new tag "fade_in_start" for make tps at the end of fade out smoother
tag @a[scores={fade=100}] add fade_in_start
execute as @a unless entity @s[scores={fade=100}] run tag @s remove fade_in_start
tag @a[scores={fade=114}] add fade_in_end
execute as @a unless entity @s[scores={fade=114}] run tag @s remove fade_in_end


# Complete dissolve: automatically follows a fade out with a fade in and changes the items of the player for a dialogue
# Only dissolve effect
execute as @a[tag=dissolve] unless entity @s[scores={fade=1..}] run tag @s add fade_out_F
tag @a[tag=dissolve,tag=fade_out_end] add fade_in_F
tag @a[tag=dissolve,tag=fade_in_end] remove dissolve

# Dissolve for start of dialogues
execute as @a[tag=dissolve_start] unless entity @s[scores={fade=1..}] run tag @s add fade_out_F
tag @a[tag=dissolve_start,tag=fade_out_end] add fade_in_F
tag @a[tag=dissolve_start,tag=fade_in_end] remove dissolve_start

execute as @a[tag=dissolve_start,tag=fade_out_end] run data modify entity @e[limit=1,tag=player_puppet] HandItems[0] set from entity @s SelectedItem
execute as @a[tag=dissolve_start,tag=fade_out_end] run replaceitem entity @s weapon.mainhand coal{CustomModelData:8,display:{Name:"[{\"text\":\"\"}]"},clear:true}

# Dissolve for end of dialogues
execute as @a[tag=dissolve_end] unless entity @s[scores={fade=1..}] run tag @s add fade_out_F
tag @a[tag=dissolve_end,tag=fade_out_end] add fade_in_F
tag @a[tag=dissolve_end,tag=fade_in_end] remove dissolve_end

execute as @a[tag=dissolve_end,tag=fade_out_end] run clear @s coal{clear:true}
execute as @a[tag=dissolve_end,tag=fade_out_end] at @s run summon item ~ ~ ~ {Item:{id:black_concrete,Count:1b,tag:{mainhand:true}}}
execute as @a[tag=dissolve_end,tag=fade_out_end] at @s run data modify entity @e[type=item,limit=1,sort=nearest,nbt={Item:{tag:{mainhand:true}}}] Item set from entity @e[tag=player_puppet,limit=1] HandItems[0]
